@@ -13,7 +13,7 @@ package Printer::Thermal;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.23'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -765,7 +765,7 @@ Printer::Thermal - Interface for Thermal (and some dot-matrix and inkjet) Printe
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -975,8 +975,8 @@ Turns on emphasize(read ESC-POS documentation)
 =head2 font_size
 
 Defined Region
-0 ≤ n ≤ 255
-However, 1 ≤ vertical direction magnification ratio ≤ 8, 1 ≤ horizontal direction magnification ratio ≤ 8
+0 <= n <= 255
+However, 1 <= vertical direction magnification ratio <= 8, 1 <= horizontal direction magnification ratio <= 8
 Initial Value n=0
 Function Specifies the character size (magnification ratio in the vertical and horizontal directions).
 
@@ -1048,8 +1048,6 @@ Opens the Cash Drawer connected to the thermal printer.
 
 Prints a bunch of test strings to see if your printer is working fine/connected properly. Don't worry if some things like emphasized and double strike looks the same, it happened with my printer too.
 
-=encoding utf-8
-
 =head1 NOTES
 
 =over
